require 'spec_helper'

def normalize_config_string(config_string)
  config_string.strip.gsub('/^\n$/','').gsub(/^\s*/,'').gsub(/\s*$/,'')
end

describe Tomahawk::Generators::HTTPd do
  it "generates configs correctly" do 
    config = Tomahawk::Config.new do |directives, groups|
      directives[:timeout] = '300'
      directives[:max_keep_alive_requests] = '100'

      groups << Tomahawk::DirectiveGroups::VirtualHost.new('*:80') do |directives, groups|
        directives[:server_name] = 'example.com'
        directives[:document_root] = '/var/www/example.com'

        groups << Tomahawk::DirectiveGroups::Directory.new('/var/www/example.com') do |directives, groups|
          directives[:options] = '-Indexes FollowSymLinks MultiViews'
        end
      end
    end

    expected_result = <<-SAMPLE
      Timeout 300
      MaxKeepAliveRequests 100
        <VirtualHost *:80>

         ServerName example.com
         DocumentRoot /var/www/example.com
        <Directory /var/www/example.com>

         Options -Indexes FollowSymLinks MultiViews
        </Directory>

        </VirtualHost>
    SAMPLE
    
    expect(normalize_config_string(Tomahawk::Generators::HTTPd.new(config).to_s)).to eq(normalize_config_string(expected_result))
  end
end